@@ -27,7 +27,7 @@
 #include <Tensile/Activation.hpp>
 #include <Tensile/Utils.hpp>
 
-namespace Tensile
+namespace TensileLite
 {
     std::string ToString(ActivationType d)
     {
@@ -57,6 +57,8 @@ namespace Tensile
             return "Silu";
         case ActivationType::All:
             return "All";
+        case ActivationType::Hipblaslt_all:
+            return "Hipblaslt_all";
         case ActivationType::None:
             return "None";
         default:
@@ -121,6 +123,10 @@ namespace Tensile
         {
             t = ActivationType::All;
         }
+        else if(strValue == ToString(ActivationType::Hipblaslt_all))
+        {
+            t = ActivationType::Hipblaslt_all;
+        }
         else if(strValue == ToString(ActivationType::None))
         {
             t = ActivationType::None;
